@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -196,7 +196,8 @@ const gchar *conv_get_outgoing_charset_str	(void);
 const gchar *conv_get_current_locale		(void);
 
 gchar *conv_unmime_header		(const gchar	*str,
-                                         const gchar	*default_encoding);
+					  const gchar	*default_encoding,
+					  gboolean	 addr_field);
 void conv_encode_header			(gchar		*dest,
 					 gint		 len,
 					 const gchar	*src,
