@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -205,10 +205,6 @@ GtkWidget *stock_pixmap_widget	(GtkWidget	 *window,
 				 StockPixmap	  icon);
 gint stock_pixbuf_gdk		(GtkWidget *window, StockPixmap icon, 
 				 GdkPixbuf **pixbuf);
-gint stock_pixmap_gdk		(GtkWidget	 *window,
-				 StockPixmap	  icon,
-				 GdkPixmap	**pixmap,
-				 GdkBitmap	**mask);
 
 GList *stock_pixmap_themes_list_new	(void);
 void stock_pixmap_themes_list_free	(GList *list);
@@ -220,5 +216,6 @@ GtkWidget *stock_pixmap_widget_with_overlay (GtkWidget		*window,
 					     OverlayPosition	 pos,
 					     gint		 border_x,
 					     gint		 border_y);
+gchar *stock_pixmap_get_system_theme_dir_for_theme(const gchar *theme);
 
 #endif /* __STOCK_PIXMAP_H__ */
